@@ -148,7 +148,9 @@ checkDLL <- function (func, jacfunc, dllname,
       stop("func, initfunc, or jacfunc cannot be the same")
     ModelInit <- NA
     if (! is.null(initfunc))  # to allow absence of initfunc
-      if (is.loaded(initfunc, PACKAGE = dllname, type = "") ||
+      if (inherits (initfunc, "CFunc"))
+        ModelInit <- body(initfunc)[[2]]
+      else if (is.loaded(initfunc, PACKAGE = dllname, type = "") ||
         is.loaded(initfunc, PACKAGE = dllname, type = "Fortran"))  {
         ModelInit <- getNativeSymbolInfo(initfunc, PACKAGE = dllname)$address
       } else if (initfunc != dllname && ! is.null(initfunc))
@@ -163,7 +165,9 @@ checkDLL <- function (func, jacfunc, dllname,
     funcname <- func
     ## get the pointer and put it in func
 
-    if(is.loaded(funcname, PACKAGE = dllname)) {
+    if (inherits (func, "CFunc"))
+        Func <- body(func)[[2]]
+    else if(is.loaded(funcname, PACKAGE = dllname)) {
       Func <- getNativeSymbolInfo(funcname, PACKAGE = dllname)$address
     } else stop(paste("dyn function 'func' not loaded", funcname))
 
@@ -175,7 +179,10 @@ checkDLL <- function (func, jacfunc, dllname,
           stop("If 'func' is dynloaded, so must 'jacvec' be")
         )
       jacfuncname <- jacfunc
-      if(is.loaded(jacfuncname, PACKAGE = dllname))  {
+      if (inherits (jacfunc, "CFunc"))
+        JacFunc <- body(jacfunc)[[2]]
+
+      else if(is.loaded(jacfuncname, PACKAGE = dllname))  {
         JacFunc <- getNativeSymbolInfo(jacfuncname, PACKAGE = dllname)$address
       } else stop(paste("cannot integrate: jac function not loaded ", jacfunc))
     } else JacFunc <- NULL
